# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictStr, conint

from typing import Optional

from conekta.models.get_plans_response import GetPlansResponse
from conekta.models.plan_request import PlanRequest
from conekta.models.plan_response import PlanResponse
from conekta.models.plan_update_request import PlanUpdateRequest

from conekta.api_client import ApiClient
from conekta.api_response import ApiResponse
from conekta.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PlansApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_plan(self, plan_request : Annotated[PlanRequest, Field(..., description="requested field for plan")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> PlanResponse:  # noqa: E501
        """Create Plan  # noqa: E501

        Create a new plan for an existing order  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_plan(plan_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param plan_request: requested field for plan (required)
        :type plan_request: PlanRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PlanResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_plan_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_plan_with_http_info(plan_request, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def create_plan_with_http_info(self, plan_request : Annotated[PlanRequest, Field(..., description="requested field for plan")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create Plan  # noqa: E501

        Create a new plan for an existing order  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_plan_with_http_info(plan_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param plan_request: requested field for plan (required)
        :type plan_request: PlanRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PlanResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'plan_request',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_plan" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['plan_request'] is not None:
            _body_params = _params['plan_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PlanResponse",
            '422': "Error",
            '401': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/plans', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_plan(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, **kwargs) -> PlanResponse:  # noqa: E501
        """Delete Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_plan(id, accept_language, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PlanResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the delete_plan_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.delete_plan_with_http_info(id, accept_language, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_plan_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_plan_with_http_info(id, accept_language, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PlanResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'accept_language'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_plan" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PlanResponse",
            '422': "Error",
            '401': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/plans/{id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_plan(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> PlanResponse:  # noqa: E501
        """Get Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_plan(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PlanResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_plan_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_plan_with_http_info(id, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_plan_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_plan_with_http_info(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PlanResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plan" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PlanResponse",
            '422': "Error",
            '401': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/plans/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_plans(self, accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, limit : Annotated[Optional[conint(strict=True, le=250, ge=1)], Field(description="The numbers of items to return, the maximum value is 250")] = None, search : Annotated[Optional[StrictStr], Field(description="General order search, e.g. by mail, reference etc.")] = None, next : Annotated[Optional[StrictStr], Field(description="next page")] = None, previous : Annotated[Optional[StrictStr], Field(description="previous page")] = None, **kwargs) -> GetPlansResponse:  # noqa: E501
        """Get A List of Plans  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_plans(accept_language, x_child_company_id, limit, search, next, previous, async_req=True)
        >>> result = thread.get()

        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param limit: The numbers of items to return, the maximum value is 250
        :type limit: int
        :param search: General order search, e.g. by mail, reference etc.
        :type search: str
        :param next: next page
        :type next: str
        :param previous: previous page
        :type previous: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetPlansResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_plans_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_plans_with_http_info(accept_language, x_child_company_id, limit, search, next, previous, **kwargs)  # noqa: E501

    @validate_arguments
    def get_plans_with_http_info(self, accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, limit : Annotated[Optional[conint(strict=True, le=250, ge=1)], Field(description="The numbers of items to return, the maximum value is 250")] = None, search : Annotated[Optional[StrictStr], Field(description="General order search, e.g. by mail, reference etc.")] = None, next : Annotated[Optional[StrictStr], Field(description="next page")] = None, previous : Annotated[Optional[StrictStr], Field(description="previous page")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get A List of Plans  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_plans_with_http_info(accept_language, x_child_company_id, limit, search, next, previous, async_req=True)
        >>> result = thread.get()

        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param limit: The numbers of items to return, the maximum value is 250
        :type limit: int
        :param search: General order search, e.g. by mail, reference etc.
        :type search: str
        :param next: next page
        :type next: str
        :param previous: previous page
        :type previous: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetPlansResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'accept_language',
            'x_child_company_id',
            'limit',
            'search',
            'next',
            'previous'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plans" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('search') is not None:  # noqa: E501
            _query_params.append(('search', _params['search']))

        if _params.get('next') is not None:  # noqa: E501
            _query_params.append(('next', _params['next']))

        if _params.get('previous') is not None:  # noqa: E501
            _query_params.append(('previous', _params['previous']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GetPlansResponse",
            '422': "Error",
            '401': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/plans', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_plan(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], plan_update_request : Annotated[PlanUpdateRequest, Field(..., description="requested field for plan")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> PlanResponse:  # noqa: E501
        """Update Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_plan(id, plan_update_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param plan_update_request: requested field for plan (required)
        :type plan_update_request: PlanUpdateRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PlanResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the update_plan_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.update_plan_with_http_info(id, plan_update_request, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def update_plan_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], plan_update_request : Annotated[PlanUpdateRequest, Field(..., description="requested field for plan")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Update Plan  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_plan_with_http_info(id, plan_update_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param plan_update_request: requested field for plan (required)
        :type plan_update_request: PlanUpdateRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PlanResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'plan_update_request',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_plan" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['plan_update_request'] is not None:
            _body_params = _params['plan_update_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PlanResponse",
            '422': "Error",
            '401': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/plans/{id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from conekta.models.customer_fiscal_entities_request_address import CustomerFiscalEntitiesRequestAddress

class UpdateCustomerFiscalEntitiesResponse(BaseModel):
    """
    UpdateCustomerFiscalEntitiesResponse
    """
    address: CustomerFiscalEntitiesRequestAddress = Field(...)
    tax_id: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    phone: Optional[StrictStr] = None
    metadata: Optional[Dict[str, Dict[str, Any]]] = None
    company_name: Optional[StrictStr] = None
    id: StrictStr = Field(...)
    object: StrictStr = Field(...)
    created_at: StrictInt = Field(...)
    parent_id: Optional[StrictStr] = None
    default: Optional[StrictBool] = None
    __properties = ["address", "tax_id", "email", "phone", "metadata", "company_name", "id", "object", "created_at", "parent_id", "default"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateCustomerFiscalEntitiesResponse:
        """Create an instance of UpdateCustomerFiscalEntitiesResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateCustomerFiscalEntitiesResponse:
        """Create an instance of UpdateCustomerFiscalEntitiesResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateCustomerFiscalEntitiesResponse.parse_obj(obj)

        _obj = UpdateCustomerFiscalEntitiesResponse.parse_obj({
            "address": CustomerFiscalEntitiesRequestAddress.from_dict(obj.get("address")) if obj.get("address") is not None else None,
            "tax_id": obj.get("tax_id"),
            "email": obj.get("email"),
            "phone": obj.get("phone"),
            "metadata": obj.get("metadata"),
            "company_name": obj.get("company_name"),
            "id": obj.get("id"),
            "object": obj.get("object"),
            "created_at": obj.get("created_at"),
            "parent_id": obj.get("parent_id"),
            "default": obj.get("default")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr
from conekta.models.charge_request import ChargeRequest
from conekta.models.checkout_request import CheckoutRequest
from conekta.models.customer_shipping_contacts import CustomerShippingContacts
from conekta.models.order_discount_lines_request import OrderDiscountLinesRequest
from conekta.models.order_tax_request import OrderTaxRequest
from conekta.models.order_update_request_customer_info import OrderUpdateRequestCustomerInfo
from conekta.models.product import Product
from conekta.models.shipping_request import ShippingRequest

class OrderUpdateRequest(BaseModel):
    """
    a order
    """
    charges: Optional[conlist(ChargeRequest)] = None
    checkout: Optional[CheckoutRequest] = None
    currency: Optional[constr(strict=True, max_length=3)] = Field(None, description="Currency with which the payment will be made. It uses the 3-letter code of the [International Standard ISO 4217.](https://es.wikipedia.org/wiki/ISO_4217)")
    customer_info: Optional[OrderUpdateRequestCustomerInfo] = None
    discount_lines: Optional[conlist(OrderDiscountLinesRequest)] = Field(None, description="List of [discounts](https://developers.conekta.com/v2.1.0/reference/orderscreatediscountline) that are applied to the order. You must have at least one discount.")
    line_items: Optional[conlist(Product)] = Field(None, description="List of [products](https://developers.conekta.com/v2.1.0/reference/orderscreateproduct) that are sold in the order. You must have at least one product.")
    metadata: Optional[Dict[str, StrictStr]] = None
    pre_authorize: Optional[StrictBool] = Field(False, description="Indicates whether the order charges must be preauthorized")
    shipping_contact: Optional[CustomerShippingContacts] = None
    shipping_lines: Optional[conlist(ShippingRequest)] = Field(None, description="List of [shipping costs](https://developers.conekta.com/v2.1.0/reference/orderscreateshipping). If the online store offers digital products.")
    tax_lines: Optional[conlist(OrderTaxRequest)] = None
    __properties = ["charges", "checkout", "currency", "customer_info", "discount_lines", "line_items", "metadata", "pre_authorize", "shipping_contact", "shipping_lines", "tax_lines"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderUpdateRequest:
        """Create an instance of OrderUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in charges (list)
        _items = []
        if self.charges:
            for _item in self.charges:
                if _item:
                    _items.append(_item.to_dict())
            _dict['charges'] = _items
        # override the default output from pydantic by calling `to_dict()` of checkout
        if self.checkout:
            _dict['checkout'] = self.checkout.to_dict()
        # override the default output from pydantic by calling `to_dict()` of customer_info
        if self.customer_info:
            _dict['customer_info'] = self.customer_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in discount_lines (list)
        _items = []
        if self.discount_lines:
            for _item in self.discount_lines:
                if _item:
                    _items.append(_item.to_dict())
            _dict['discount_lines'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in line_items (list)
        _items = []
        if self.line_items:
            for _item in self.line_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['line_items'] = _items
        # override the default output from pydantic by calling `to_dict()` of shipping_contact
        if self.shipping_contact:
            _dict['shipping_contact'] = self.shipping_contact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in shipping_lines (list)
        _items = []
        if self.shipping_lines:
            for _item in self.shipping_lines:
                if _item:
                    _items.append(_item.to_dict())
            _dict['shipping_lines'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tax_lines (list)
        _items = []
        if self.tax_lines:
            for _item in self.tax_lines:
                if _item:
                    _items.append(_item.to_dict())
            _dict['tax_lines'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderUpdateRequest:
        """Create an instance of OrderUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderUpdateRequest.parse_obj(obj)

        _obj = OrderUpdateRequest.parse_obj({
            "charges": [ChargeRequest.from_dict(_item) for _item in obj.get("charges")] if obj.get("charges") is not None else None,
            "checkout": CheckoutRequest.from_dict(obj.get("checkout")) if obj.get("checkout") is not None else None,
            "currency": obj.get("currency"),
            "customer_info": OrderUpdateRequestCustomerInfo.from_dict(obj.get("customer_info")) if obj.get("customer_info") is not None else None,
            "discount_lines": [OrderDiscountLinesRequest.from_dict(_item) for _item in obj.get("discount_lines")] if obj.get("discount_lines") is not None else None,
            "line_items": [Product.from_dict(_item) for _item in obj.get("line_items")] if obj.get("line_items") is not None else None,
            "metadata": obj.get("metadata"),
            "pre_authorize": obj.get("pre_authorize") if obj.get("pre_authorize") is not None else False,
            "shipping_contact": CustomerShippingContacts.from_dict(obj.get("shipping_contact")) if obj.get("shipping_contact") is not None else None,
            "shipping_lines": [ShippingRequest.from_dict(_item) for _item in obj.get("shipping_lines")] if obj.get("shipping_lines") is not None else None,
            "tax_lines": [OrderTaxRequest.from_dict(_item) for _item in obj.get("tax_lines")] if obj.get("tax_lines") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""

from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.orders_api import OrdersApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.orders_api.OrdersApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        Cancel Order  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.cancel_order('ord_2tqaGQYZyvBsMKEgs', accept_language)
        self.assertIsNotNone(response)

    def test_create_order(self):
        """Test case for create_order

        Create order  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.OrderRequest(
            currency='MXN',
            customer_info=conekta.OrderRequestCustomerInfo(
                oneof_schema_2_validator=conekta.CustomerInfoJustCustomerId(
                    customer_id='cus_2tYENskzTjjgkGQLt'
                )
            ),
            line_items=[conekta.Product(
                name='product',
                quantity=1,
                unit_price=1000
            )]
        )
        response = self.api.create_order(rq, accept_language)
        self.assertIsNotNone(response)

    def test_get_order_by_id(self):
        """Test case for get_order_by_id

        Get Order  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_order_by_id('ord_2tUigJ8DgBhbp6w5D', accept_language)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.charges)
        self.assertIsNotNone(response.charges.data)
        charge = response.charges.data[0]
        self.assertIsNotNone(charge.payment_method)
        self.assertIsInstance(charge.payment_method.actual_instance, conekta.PaymentMethodBankTransfer)
        self.assertEqual('spei', charge.payment_method.actual_instance.type)

    def test_get_orders(self):
        """Test case for get_orders

        Get a list of Orders  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_orders(accept_language, limit=20)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.data)
        self.assertIsNotNone(response.data)
        self.assertIsNotNone(response.data[0].charges)
        self.assertIsNotNone(response.data[0].charges.data)
        charge = response.data[0].charges.data[0]
        self.assertIsNotNone(charge.payment_method)
        self.assertIsInstance(charge.payment_method.actual_instance, conekta.PaymentMethodCard)
        self.assertEqual('credit', charge.payment_method.actual_instance.type)

    def test_order_cancel_refund(self):
        """Test case for order_cancel_refund

        Cancel Refund  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.order_cancel_refund('ord_2tV52JvSom2w3E8bX', '6407b5bee1329a000175ba11', accept_language)
        self.assertIsNotNone(response)

    def test_order_refund(self):
        """Test case for order_refund

        Refund Order  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.OrderRefundRequest(
            amount=2000,
            reason='promo'
        )
        response = self.api.order_refund('ord_2tV52JvSom2w3E8bX', rq, accept_language)
        self.assertIsNotNone(response)

    def test_orders_create_capture(self):
        """Test case for orders_create_capture

        Capture Order  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.orders_create_capture('ord_2tV52JvSom2w3E8bX', accept_language)
        self.assertIsNotNone(response)

    def test_update_order(self):
        """Test case for update_order

        Update Order  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.OrderUpdateRequest(
            currency='MXN'
        )
        response = self.api.update_order('ord_2tV52JvSom2w3E8bX', rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, constr
from conekta.models.transfer_destination_response import TransferDestinationResponse

class TransferResponse(BaseModel):
    """
    A transfer represents the action of sending an amount to a business bank account including the status, amount and method used to make the transfer.
    """
    amount: Optional[StrictInt] = Field(None, description="Amount in cents of the transfer.")
    created_at: Optional[StrictInt] = Field(None, description="Date and time of creation of the transfer in Unix format.")
    currency: Optional[constr(strict=True, max_length=3)] = Field(None, description="The currency of the transfer. It uses the 3-letter code of the [International Standard ISO 4217.](https://es.wikipedia.org/wiki/ISO_4217)")
    id: Optional[StrictStr] = Field(None, description="Unique identifier of the transfer.")
    livemode: Optional[StrictBool] = Field(None, description="Indicates whether the transfer was created in live mode or test mode.")
    destination: Optional[TransferDestinationResponse] = None
    object: Optional[StrictStr] = Field(None, description="Object name, which is transfer.")
    statement_description: Optional[StrictStr] = Field(None, description="Description of the transfer.")
    statement_reference: Optional[StrictStr] = Field(None, description="Reference number of the transfer.")
    status: Optional[StrictStr] = Field(None, description="Code indicating transfer status.")
    __properties = ["amount", "created_at", "currency", "id", "livemode", "destination", "object", "statement_description", "statement_reference", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransferResponse:
        """Create an instance of TransferResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of destination
        if self.destination:
            _dict['destination'] = self.destination.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransferResponse:
        """Create an instance of TransferResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TransferResponse.parse_obj(obj)

        _obj = TransferResponse.parse_obj({
            "amount": obj.get("amount"),
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "destination": TransferDestinationResponse.from_dict(obj.get("destination")) if obj.get("destination") is not None else None,
            "object": obj.get("object"),
            "statement_description": obj.get("statement_description"),
            "statement_reference": obj.get("statement_reference"),
            "status": obj.get("status")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist

class PaymentMethodBankTransfer(BaseModel):
    """
    PaymentMethodBankTransfer
    """
    type: Optional[StrictStr] = None
    object: StrictStr = Field(...)
    bank: Optional[StrictStr] = None
    clabe: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    executed_at: Optional[StrictInt] = None
    expires_at: Optional[StrictInt] = None
    issuing_account_bank: Optional[StrictStr] = None
    issuing_account_number: Optional[StrictStr] = None
    issuing_account_holder_name: Optional[StrictStr] = None
    issuing_account_tax_id: Optional[StrictStr] = None
    payment_attempts: Optional[conlist(Any)] = None
    receiving_account_holder_name: Optional[StrictStr] = None
    receiving_account_number: Optional[StrictStr] = None
    receiving_account_bank: Optional[StrictStr] = None
    receiving_account_tax_id: Optional[StrictStr] = None
    reference_number: Optional[StrictStr] = None
    tracking_code: Optional[StrictStr] = None
    __properties = ["type", "object", "bank", "clabe", "description", "executed_at", "expires_at", "issuing_account_bank", "issuing_account_number", "issuing_account_holder_name", "issuing_account_tax_id", "payment_attempts", "receiving_account_holder_name", "receiving_account_number", "receiving_account_bank", "receiving_account_tax_id", "reference_number", "tracking_code"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PaymentMethodBankTransfer:
        """Create an instance of PaymentMethodBankTransfer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict['description'] = None

        # set to None if executed_at (nullable) is None
        # and __fields_set__ contains the field
        if self.executed_at is None and "executed_at" in self.__fields_set__:
            _dict['executed_at'] = None

        # set to None if issuing_account_bank (nullable) is None
        # and __fields_set__ contains the field
        if self.issuing_account_bank is None and "issuing_account_bank" in self.__fields_set__:
            _dict['issuing_account_bank'] = None

        # set to None if issuing_account_number (nullable) is None
        # and __fields_set__ contains the field
        if self.issuing_account_number is None and "issuing_account_number" in self.__fields_set__:
            _dict['issuing_account_number'] = None

        # set to None if issuing_account_holder_name (nullable) is None
        # and __fields_set__ contains the field
        if self.issuing_account_holder_name is None and "issuing_account_holder_name" in self.__fields_set__:
            _dict['issuing_account_holder_name'] = None

        # set to None if issuing_account_tax_id (nullable) is None
        # and __fields_set__ contains the field
        if self.issuing_account_tax_id is None and "issuing_account_tax_id" in self.__fields_set__:
            _dict['issuing_account_tax_id'] = None

        # set to None if receiving_account_holder_name (nullable) is None
        # and __fields_set__ contains the field
        if self.receiving_account_holder_name is None and "receiving_account_holder_name" in self.__fields_set__:
            _dict['receiving_account_holder_name'] = None

        # set to None if receiving_account_tax_id (nullable) is None
        # and __fields_set__ contains the field
        if self.receiving_account_tax_id is None and "receiving_account_tax_id" in self.__fields_set__:
            _dict['receiving_account_tax_id'] = None

        # set to None if reference_number (nullable) is None
        # and __fields_set__ contains the field
        if self.reference_number is None and "reference_number" in self.__fields_set__:
            _dict['reference_number'] = None

        # set to None if tracking_code (nullable) is None
        # and __fields_set__ contains the field
        if self.tracking_code is None and "tracking_code" in self.__fields_set__:
            _dict['tracking_code'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PaymentMethodBankTransfer:
        """Create an instance of PaymentMethodBankTransfer from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PaymentMethodBankTransfer.parse_obj(obj)

        _obj = PaymentMethodBankTransfer.parse_obj({
            "type": obj.get("type"),
            "object": obj.get("object"),
            "bank": obj.get("bank"),
            "clabe": obj.get("clabe"),
            "description": obj.get("description"),
            "executed_at": obj.get("executed_at"),
            "expires_at": obj.get("expires_at"),
            "issuing_account_bank": obj.get("issuing_account_bank"),
            "issuing_account_number": obj.get("issuing_account_number"),
            "issuing_account_holder_name": obj.get("issuing_account_holder_name"),
            "issuing_account_tax_id": obj.get("issuing_account_tax_id"),
            "payment_attempts": obj.get("payment_attempts"),
            "receiving_account_holder_name": obj.get("receiving_account_holder_name"),
            "receiving_account_number": obj.get("receiving_account_number"),
            "receiving_account_bank": obj.get("receiving_account_bank"),
            "receiving_account_tax_id": obj.get("receiving_account_tax_id"),
            "reference_number": obj.get("reference_number"),
            "tracking_code": obj.get("tracking_code")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from conekta.models.charge_response_channel import ChargeResponseChannel
from conekta.models.order_response_charges import OrderResponseCharges
from conekta.models.order_response_checkout import OrderResponseCheckout
from conekta.models.order_response_customer_info import OrderResponseCustomerInfo
from conekta.models.order_response_discount_lines import OrderResponseDiscountLines
from conekta.models.order_response_fiscal_entity import OrderResponseFiscalEntity
from conekta.models.order_response_products import OrderResponseProducts
from conekta.models.order_response_shipping_contact import OrderResponseShippingContact

class OrderResponse(BaseModel):
    """
    order response
    """
    amount: Optional[StrictInt] = Field(None, description="The total amount to be collected in cents")
    amount_refunded: Optional[StrictInt] = Field(None, description="The total amount refunded in cents")
    channel: Optional[ChargeResponseChannel] = None
    charges: Optional[OrderResponseCharges] = None
    checkout: Optional[OrderResponseCheckout] = None
    created_at: Optional[StrictInt] = Field(None, description="The time at which the object was created in seconds since the Unix epoch")
    currency: Optional[StrictStr] = Field(None, description="The three-letter ISO 4217 currency code. The currency of the order.")
    customer_info: Optional[OrderResponseCustomerInfo] = None
    discount_lines: Optional[OrderResponseDiscountLines] = None
    fiscal_entity: Optional[OrderResponseFiscalEntity] = None
    id: Optional[StrictStr] = None
    is_refundable: Optional[StrictBool] = None
    line_items: Optional[OrderResponseProducts] = None
    livemode: Optional[StrictBool] = Field(None, description="Whether the object exists in live mode or test mode")
    metadata: Optional[Dict[str, Any]] = Field(None, description="Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.")
    object: Optional[StrictStr] = Field(None, description="String representing the object’s type. Objects of the same type share the same value.")
    payment_status: Optional[StrictStr] = Field(None, description="The payment status of the order.")
    processing_mode: Optional[StrictStr] = Field(None, description="Indicates the processing mode for the order, either ecommerce, recurrent or validation.")
    shipping_contact: Optional[OrderResponseShippingContact] = None
    updated_at: Optional[StrictInt] = Field(None, description="The time at which the object was last updated in seconds since the Unix epoch")
    __properties = ["amount", "amount_refunded", "channel", "charges", "checkout", "created_at", "currency", "customer_info", "discount_lines", "fiscal_entity", "id", "is_refundable", "line_items", "livemode", "metadata", "object", "payment_status", "processing_mode", "shipping_contact", "updated_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderResponse:
        """Create an instance of OrderResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of channel
        if self.channel:
            _dict['channel'] = self.channel.to_dict()
        # override the default output from pydantic by calling `to_dict()` of charges
        if self.charges:
            _dict['charges'] = self.charges.to_dict()
        # override the default output from pydantic by calling `to_dict()` of checkout
        if self.checkout:
            _dict['checkout'] = self.checkout.to_dict()
        # override the default output from pydantic by calling `to_dict()` of customer_info
        if self.customer_info:
            _dict['customer_info'] = self.customer_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of discount_lines
        if self.discount_lines:
            _dict['discount_lines'] = self.discount_lines.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fiscal_entity
        if self.fiscal_entity:
            _dict['fiscal_entity'] = self.fiscal_entity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of line_items
        if self.line_items:
            _dict['line_items'] = self.line_items.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shipping_contact
        if self.shipping_contact:
            _dict['shipping_contact'] = self.shipping_contact.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderResponse:
        """Create an instance of OrderResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderResponse.parse_obj(obj)

        _obj = OrderResponse.parse_obj({
            "amount": obj.get("amount"),
            "amount_refunded": obj.get("amount_refunded"),
            "channel": ChargeResponseChannel.from_dict(obj.get("channel")) if obj.get("channel") is not None else None,
            "charges": OrderResponseCharges.from_dict(obj.get("charges")) if obj.get("charges") is not None else None,
            "checkout": OrderResponseCheckout.from_dict(obj.get("checkout")) if obj.get("checkout") is not None else None,
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "customer_info": OrderResponseCustomerInfo.from_dict(obj.get("customer_info")) if obj.get("customer_info") is not None else None,
            "discount_lines": OrderResponseDiscountLines.from_dict(obj.get("discount_lines")) if obj.get("discount_lines") is not None else None,
            "fiscal_entity": OrderResponseFiscalEntity.from_dict(obj.get("fiscal_entity")) if obj.get("fiscal_entity") is not None else None,
            "id": obj.get("id"),
            "is_refundable": obj.get("is_refundable"),
            "line_items": OrderResponseProducts.from_dict(obj.get("line_items")) if obj.get("line_items") is not None else None,
            "livemode": obj.get("livemode"),
            "metadata": obj.get("metadata"),
            "object": obj.get("object"),
            "payment_status": obj.get("payment_status"),
            "processing_mode": obj.get("processing_mode"),
            "shipping_contact": OrderResponseShippingContact.from_dict(obj.get("shipping_contact")) if obj.get("shipping_contact") is not None else None,
            "updated_at": obj.get("updated_at")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.webhooks_api import WebhooksApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.webhooks_api.WebhooksApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_webhook(self):
        """Test case for create_webhook

        Create Webhook  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.WebhookRequest(
            url='http://api.test.com',
            synchronous=False
        )
        response = self.api.create_webhook(rq, accept_language)
        self.assertIsNotNone(response)

    def test_delete_webhook(self):
        """Test case for delete_webhook

        Delete Webhook  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_webhook('641b1d5662d7e00001eaa46b', accept_language)
        self.assertIsNotNone(response)

    def test_get_webhook(self):
        """Test case for get_webhook

        Get Webhook  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_webhook('641b1d5662d7e00001eaa46b', accept_language)
        self.assertIsNotNone(response)

    def test_get_webhooks(self):
        """Test case for get_webhooks

        Get List of Webhooks  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_webhooks(accept_language, limit=20)
        self.assertIsNotNone(response)

    def test_test_webhook(self):
        """Test case for test_webhook

        Test Webhook  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.test_webhook('641b1d5662d7e00001eaa46b', accept_language)
        self.assertIsNotNone(response)

    def test_update_webhook(self):
        """Test case for update_webhook

        Update Webhook  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.WebhookUpdateRequest(
            url='http://api.test.com',
            synchronous=False
        )
        response = self.api.update_webhook('641b1d5662d7e00001eaa46b', rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conlist
from conekta.models.webhook_log import WebhookLog

class EventResponse(BaseModel):
    """
    event model
    """
    created_at: Optional[StrictInt] = None
    data: Optional[Dict[str, Any]] = None
    id: Optional[StrictStr] = None
    livemode: Optional[StrictBool] = None
    object: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    webhook_logs: Optional[conlist(WebhookLog)] = None
    webhook_status: Optional[StrictStr] = None
    __properties = ["created_at", "data", "id", "livemode", "object", "type", "webhook_logs", "webhook_status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EventResponse:
        """Create an instance of EventResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in webhook_logs (list)
        _items = []
        if self.webhook_logs:
            for _item in self.webhook_logs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['webhook_logs'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EventResponse:
        """Create an instance of EventResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EventResponse.parse_obj(obj)

        _obj = EventResponse.parse_obj({
            "created_at": obj.get("created_at"),
            "data": obj.get("data"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "object": obj.get("object"),
            "type": obj.get("type"),
            "webhook_logs": [WebhookLog.from_dict(_item) for _item in obj.get("webhook_logs")] if obj.get("webhook_logs") is not None else None,
            "webhook_status": obj.get("webhook_status")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator

class CompanyPayoutDestinationResponse(BaseModel):
    """
    Company payout destination model
    """
    object: Optional[StrictStr] = Field(None, description="The resource's type")
    currency: Optional[StrictStr] = Field(None, description="currency of the receiving account")
    account_holder_name: Optional[StrictStr] = Field(None, description="Name of the account holder")
    bank: Optional[StrictStr] = Field(None, description="Name of the bank")
    type: Optional[StrictStr] = Field(None, description="Type of the payout destination")
    account_number: Optional[StrictStr] = Field(None, description="Account number of the receiving account")
    __properties = ["object", "currency", "account_holder_name", "bank", "type", "account_number"]

    @validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('payout_destination'):
            raise ValueError("must be one of enum values ('payout_destination')")
        return value

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('bank_account'):
            raise ValueError("must be one of enum values ('bank_account')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CompanyPayoutDestinationResponse:
        """Create an instance of CompanyPayoutDestinationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CompanyPayoutDestinationResponse:
        """Create an instance of CompanyPayoutDestinationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CompanyPayoutDestinationResponse.parse_obj(obj)

        _obj = CompanyPayoutDestinationResponse.parse_obj({
            "object": obj.get("object"),
            "currency": obj.get("currency"),
            "account_holder_name": obj.get("account_holder_name"),
            "bank": obj.get("bank"),
            "type": obj.get("type"),
            "account_number": obj.get("account_number")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.payment_methods_api import PaymentMethodsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestPaymentMethodsApi(unittest.TestCase):
    """PaymentMethodsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.payment_methods_api.PaymentMethodsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer_payment_methods(self):
        """Test case for create_customer_payment_methods

        Create Payment Method  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.CreateCustomerPaymentMethodsRequest(
            conekta.PaymentMethodCashRequest(
                type='oxxo_recurrent'
            )
        )
            
        response = self.api.create_customer_payment_methods('cus_2tXyF9BwPG14UMkkg', rq, accept_language)
        self.assertIsNotNone(response)
        self.assertIsInstance(response.actual_instance, conekta.PaymentMethodCashResponse)
        self.assertEqual('oxxo_recurrent', response.actual_instance.type)

    def test_delete_customer_payment_methods(self):
        """Test case for delete_customer_payment_methods

        Delete Payment Method  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_customer_payment_methods('cus_2tYENskzTjjgkGQLt', 'src_2tbd5Bgy67RL9oycM',
                                                            accept_language)
        self.assertIsNotNone(response)

    def test_get_customer_payment_methods(self):
        """Test case for get_customer_payment_methods

        Get Payment Methods  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_customer_payment_methods('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.data)
        self.assertIsInstance(response.data[0].actual_instance, conekta.PaymentMethodCardResponse)
        self.assertEqual('card', response.data[0].actual_instance.type)

    def test_update_customer_payment_methods(self):
        """Test case for update_customer_payment_methods

        Update Payment Method  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.UpdatePaymentMethods(
            name='test'
        )
        response = self.api.update_customer_payment_methods('cus_2tYENskzTjjgkGQLt', 'src_2tbd5Bgy67RL9oycM', rq,
                                                            accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist

class WebhookResponse(BaseModel):
    """
    webhooks model
    """
    deleted: Optional[StrictBool] = None
    development_enabled: Optional[StrictBool] = None
    id: Optional[StrictStr] = None
    livemode: Optional[StrictBool] = None
    object: Optional[StrictStr] = None
    production_enabled: Optional[StrictBool] = None
    status: Optional[StrictStr] = None
    subscribed_events: Optional[conlist(StrictStr)] = None
    synchronous: Optional[StrictBool] = None
    url: Optional[StrictStr] = None
    __properties = ["deleted", "development_enabled", "id", "livemode", "object", "production_enabled", "status", "subscribed_events", "synchronous", "url"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebhookResponse:
        """Create an instance of WebhookResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if deleted (nullable) is None
        # and __fields_set__ contains the field
        if self.deleted is None and "deleted" in self.__fields_set__:
            _dict['deleted'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebhookResponse:
        """Create an instance of WebhookResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebhookResponse.parse_obj(obj)

        _obj = WebhookResponse.parse_obj({
            "deleted": obj.get("deleted"),
            "development_enabled": obj.get("development_enabled"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "object": obj.get("object"),
            "production_enabled": obj.get("production_enabled"),
            "status": obj.get("status"),
            "subscribed_events": obj.get("subscribed_events"),
            "synchronous": obj.get("synchronous"),
            "url": obj.get("url")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.plans_api import PlansApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestPlansApi(unittest.TestCase):
    """PlansApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.plans_api.PlansApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_plan(self):
        """Test case for create_plan

        Create Plan  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.PlanRequest(
            amount=1000,
            currency='MXN',
            frequency=1,
            interval='week',
            name='plan test'
        )
        response = self.api.create_plan(rq, accept_language)
        self.assertIsNotNone(response)

    def test_delete_plan(self):
        """Test case for delete_plan

        Delete Plan  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_plan('plan_2tZb5q8Z3PYpg6SJd', accept_language)
        self.assertIsNotNone(response)

    def test_get_plan(self):
        """Test case for get_plan

        Get Plan  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_plan('plan_2tZb5q8Z3PYpg6SJd', accept_language)
        self.assertIsNotNone(response)

    def test_get_plans(self):
        """Test case for get_plans

        Get A List of Plans  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_plans(accept_language, limit=20)
        self.assertIsNotNone(response)

    def test_update_plan(self):
        """Test case for update_plan

        Update Plan  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.PlanUpdateRequest(
            amount=1000
        )
        response = self.api.update_plan('plan_2tZb5q8Z3PYpg6SJd', rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt, StrictStr

class PaymentMethodCashResponseAllOf(BaseModel):
    """
    use for cash responses
    """
    reference: Optional[StrictStr] = None
    barcode: Optional[StrictStr] = None
    barcode_url: Optional[StrictStr] = None
    expires_at: Optional[StrictInt] = None
    provider: Optional[StrictStr] = None
    __properties = ["reference", "barcode", "barcode_url", "expires_at", "provider"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PaymentMethodCashResponseAllOf:
        """Create an instance of PaymentMethodCashResponseAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PaymentMethodCashResponseAllOf:
        """Create an instance of PaymentMethodCashResponseAllOf from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PaymentMethodCashResponseAllOf.parse_obj(obj)

        _obj = PaymentMethodCashResponseAllOf.parse_obj({
            "reference": obj.get("reference"),
            "barcode": obj.get("barcode"),
            "barcode_url": obj.get("barcode_url"),
            "expires_at": obj.get("expires_at"),
            "provider": obj.get("provider")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class TransferMethodResponse(BaseModel):
    """
    Method used to make the transfer.
    """
    account_holder: Optional[StrictStr] = Field(None, description="Name of the account holder.")
    account_number: Optional[StrictStr] = Field(None, description="Account number of the bank account.")
    bank: Optional[StrictStr] = Field(None, description="Name of the bank.")
    created_at: Optional[StrictInt] = Field(None, description="Date and time of creation of the transfer.")
    id: Optional[StrictStr] = Field(None, description="Unique identifier of the transfer.")
    object: Optional[StrictStr] = Field(None, description="Object name, which is bank_transfer_payout_method.")
    payee_id: Optional[StrictStr] = Field(None, description="Unique identifier of the payee.")
    type: Optional[StrictStr] = Field(None, description="Type of the payee.")
    __properties = ["account_holder", "account_number", "bank", "created_at", "id", "object", "payee_id", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransferMethodResponse:
        """Create an instance of TransferMethodResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransferMethodResponse:
        """Create an instance of TransferMethodResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TransferMethodResponse.parse_obj(obj)

        _obj = TransferMethodResponse.parse_obj({
            "account_holder": obj.get("account_holder"),
            "account_number": obj.get("account_number"),
            "bank": obj.get("bank"),
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "object": obj.get("object"),
            "payee_id": obj.get("payee_id"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from conekta.models.company_fiscal_info_address_response import CompanyFiscalInfoAddressResponse

class CompanyFiscalInfoResponse(BaseModel):
    """
    Company fiscal info model
    """
    object: Optional[StrictStr] = Field(None, description="The resource's type")
    tax_id: Optional[StrictStr] = Field(None, description="Tax ID of the company")
    legal_entity_name: Optional[StrictStr] = Field(None, description="Legal name of the company")
    business_type: Optional[StrictStr] = Field(None, description="Business type of the company")
    phone: Optional[StrictStr] = Field(None, description="Phone number of the company")
    physical_person_business_type: Optional[StrictStr] = Field(None, description="Business type if 'persona_fisica'")
    address: Optional[CompanyFiscalInfoAddressResponse] = None
    __properties = ["object", "tax_id", "legal_entity_name", "business_type", "phone", "physical_person_business_type", "address"]

    @validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('fiscal_info'):
            raise ValueError("must be one of enum values ('fiscal_info')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CompanyFiscalInfoResponse:
        """Create an instance of CompanyFiscalInfoResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CompanyFiscalInfoResponse:
        """Create an instance of CompanyFiscalInfoResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CompanyFiscalInfoResponse.parse_obj(obj)

        _obj = CompanyFiscalInfoResponse.parse_obj({
            "object": obj.get("object"),
            "tax_id": obj.get("tax_id"),
            "legal_entity_name": obj.get("legal_entity_name"),
            "business_type": obj.get("business_type"),
            "phone": obj.get("phone"),
            "physical_person_business_type": obj.get("physical_person_business_type"),
            "address": CompanyFiscalInfoAddressResponse.from_dict(obj.get("address")) if obj.get("address") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from conekta.models.customer_fiscal_entities_request import CustomerFiscalEntitiesRequest
from conekta.models.customer_payment_methods_request import CustomerPaymentMethodsRequest
from conekta.models.customer_shipping_contacts import CustomerShippingContacts
from conekta.models.subscription_request import SubscriptionRequest
from conekta.models.update_customer_antifraud_info import UpdateCustomerAntifraudInfo

class UpdateCustomer(BaseModel):
    """
    update customer
    """
    antifraud_info: Optional[UpdateCustomerAntifraudInfo] = None
    default_payment_source_id: Optional[StrictStr] = Field(None, description="It is a parameter that allows to identify in the response, the Conekta ID of a payment method (payment_id)")
    email: Optional[StrictStr] = Field(None, description="An email address is a series of customizable characters followed by a universal Internet symbol, the at symbol (@), the name of a host server, and a web domain ending (.mx, .com, .org, . net, etc).")
    name: Optional[StrictStr] = Field(None, description="Client's name")
    phone: Optional[StrictStr] = Field(None, description="Is the customer's phone number")
    plan_id: Optional[StrictStr] = Field(None, description="Contains the ID of a plan, which could together with name, email and phone create a client directly to a subscription")
    default_shipping_contact_id: Optional[StrictStr] = Field(None, description="It is a parameter that allows to identify in the response, the Conekta ID of the shipping address (shipping_contact)")
    corporate: Optional[StrictBool] = Field(False, description="It is a value that allows identifying if the email is corporate or not.")
    custom_reference: Optional[StrictStr] = Field(None, description="It is an undefined value.")
    fiscal_entities: Optional[conlist(CustomerFiscalEntitiesRequest)] = None
    metadata: Optional[Dict[str, Any]] = None
    payment_sources: Optional[conlist(CustomerPaymentMethodsRequest)] = Field(None, description="Contains details of the payment methods that the customer has active or has used in Conekta")
    shipping_contacts: Optional[conlist(CustomerShippingContacts)] = Field(None, description="Contains the detail of the shipping addresses that the client has active or has used in Conekta")
    subscription: Optional[SubscriptionRequest] = None
    __properties = ["antifraud_info", "default_payment_source_id", "email", "name", "phone", "plan_id", "default_shipping_contact_id", "corporate", "custom_reference", "fiscal_entities", "metadata", "payment_sources", "shipping_contacts", "subscription"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateCustomer:
        """Create an instance of UpdateCustomer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of antifraud_info
        if self.antifraud_info:
            _dict['antifraud_info'] = self.antifraud_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in fiscal_entities (list)
        _items = []
        if self.fiscal_entities:
            for _item in self.fiscal_entities:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fiscal_entities'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in payment_sources (list)
        _items = []
        if self.payment_sources:
            for _item in self.payment_sources:
                if _item:
                    _items.append(_item.to_dict())
            _dict['payment_sources'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in shipping_contacts (list)
        _items = []
        if self.shipping_contacts:
            for _item in self.shipping_contacts:
                if _item:
                    _items.append(_item.to_dict())
            _dict['shipping_contacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        # set to None if antifraud_info (nullable) is None
        # and __fields_set__ contains the field
        if self.antifraud_info is None and "antifraud_info" in self.__fields_set__:
            _dict['antifraud_info'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateCustomer:
        """Create an instance of UpdateCustomer from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateCustomer.parse_obj(obj)

        _obj = UpdateCustomer.parse_obj({
            "antifraud_info": UpdateCustomerAntifraudInfo.from_dict(obj.get("antifraud_info")) if obj.get("antifraud_info") is not None else None,
            "default_payment_source_id": obj.get("default_payment_source_id"),
            "email": obj.get("email"),
            "name": obj.get("name"),
            "phone": obj.get("phone"),
            "plan_id": obj.get("plan_id"),
            "default_shipping_contact_id": obj.get("default_shipping_contact_id"),
            "corporate": obj.get("corporate") if obj.get("corporate") is not None else False,
            "custom_reference": obj.get("custom_reference"),
            "fiscal_entities": [CustomerFiscalEntitiesRequest.from_dict(_item) for _item in obj.get("fiscal_entities")] if obj.get("fiscal_entities") is not None else None,
            "metadata": obj.get("metadata"),
            "payment_sources": [CustomerPaymentMethodsRequest.from_dict(_item) for _item in obj.get("payment_sources")] if obj.get("payment_sources") is not None else None,
            "shipping_contacts": [CustomerShippingContacts.from_dict(_item) for _item in obj.get("shipping_contacts")] if obj.get("shipping_contacts") is not None else None,
            "subscription": SubscriptionRequest.from_dict(obj.get("subscription")) if obj.get("subscription") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.logs_api import LogsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.logs_api.LogsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_get_log_by_id(self):
        """Test case for get_log_by_id

        Get Log  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_log_by_id('6419dd15b985080001fc280e', accept_language)
        self.assertIsNotNone(response)

    def test_get_logs(self):
        """Test case for get_logs

        Get List Of Logs  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_logs(accept_language, limit=20)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.customers_api import CustomersApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.customers_api.CustomersApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer(self):
        """Test case for create_customer

        Create customer  # noqa: E501
        """
        accept_language = 'es'
        customer = conekta.Customer(
            email='foo@foo.com',
            name='Foo Foo',
            phone='5534343434'
        )
        response = self.api.create_customer(customer, accept_language)
        self.assertIsNotNone(response)

    def test_create_customer_fiscal_entities(self):
        """Test case for create_customer_fiscal_entities

        Create Fiscal Entity  # noqa: E501
        """
        accept_language = 'es'
        customer = conekta.CustomerFiscalEntitiesRequest(
            email='foo@foo.com',
            company_name='Foo Foo',
            phone='5534343434',
            address=conekta.CustomerFiscalEntitiesRequestAddress(
                street1='street',
                postal_code='1444',
                city='CDMX'
            )
        )
        response = self.api.create_customer_fiscal_entities('cus_2tYENskzTjjgkGQLt', customer, accept_language)
        self.assertIsNotNone(response)

    def test_delete_customer_by_id(self):
        """Test case for delete_customer_by_id

        Delete Customer  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_customer_by_id('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_get_customer_by_id(self):
        """Test case for get_customer_by_id

        Get Customer  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_customer_by_id('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.payment_sources)
        self.assertIsNotNone(response.payment_sources.data)
        self.assertIsInstance(response.payment_sources.data[0].actual_instance, conekta.PaymentMethodCardResponse)
        self.assertEqual('card', response.payment_sources.data[0].actual_instance.type)

    def test_get_customers(self):
        """Test case for get_customers

        Get a list of customers  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_customers(accept_language, limit=20)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.data)
        self.assertIsNotNone(response.data[0].payment_sources)
        self.assertIsNotNone(response.data[0].payment_sources.data)
        self.assertIsInstance(response.data[0].payment_sources.data[0].actual_instance,
                              conekta.PaymentMethodSpeiRecurrent)
        self.assertEqual('spei_recurrent', response.data[0].payment_sources.data[0].actual_instance.type)

    def test_update_customer(self):
        """Test case for update_customer

        Update customer  # noqa: E501
        """
        accept_language = 'es'
        customer = conekta.UpdateCustomer(
            email='foo@foo.com'
        )
        response = self.api.update_customer('cus_2tYENskzTjjgkGQLt', customer, accept_language)
        self.assertIsNotNone(response)

    def test_update_customer_fiscal_entities(self):
        """Test case for update_customer_fiscal_entities

        Update  Fiscal Entity  # noqa: E501
        """
        accept_language = 'es'
        customer = conekta.CustomerUpdateFiscalEntitiesRequest(
            company_name='Foo Foo'
        )
        response = self.api.update_customer_fiscal_entities('cus_2tYENskzTjjgkGQLt', 'fis_ent_2tYENskzTjjgkGQLr', customer, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from conekta.models.order_response_fiscal_entity_address import OrderResponseFiscalEntityAddress

class OrderResponseFiscalEntity(BaseModel):
    """
    OrderResponseFiscalEntity
    """
    address: Optional[OrderResponseFiscalEntityAddress] = None
    tax_id: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    object: Optional[StrictStr] = None
    __properties = ["address", "tax_id", "id", "object"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderResponseFiscalEntity:
        """Create an instance of OrderResponseFiscalEntity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderResponseFiscalEntity:
        """Create an instance of OrderResponseFiscalEntity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderResponseFiscalEntity.parse_obj(obj)

        _obj = OrderResponseFiscalEntity.parse_obj({
            "address": OrderResponseFiscalEntityAddress.from_dict(obj.get("address")) if obj.get("address") is not None else None,
            "tax_id": obj.get("tax_id"),
            "id": obj.get("id"),
            "object": obj.get("object")
        })
        return _obj




# flake8: noqa

# import apis into api package
from conekta.api.antifraud_api import AntifraudApi
from conekta.api.api_keys_api import ApiKeysApi
from conekta.api.balances_api import BalancesApi
from conekta.api.charges_api import ChargesApi
from conekta.api.companies_api import CompaniesApi
from conekta.api.customers_api import CustomersApi
from conekta.api.discounts_api import DiscountsApi
from conekta.api.events_api import EventsApi
from conekta.api.logs_api import LogsApi
from conekta.api.orders_api import OrdersApi
from conekta.api.payment_link_api import PaymentLinkApi
from conekta.api.payment_methods_api import PaymentMethodsApi
from conekta.api.plans_api import PlansApi
from conekta.api.products_api import ProductsApi
from conekta.api.shipping_contacts_api import ShippingContactsApi
from conekta.api.shippings_api import ShippingsApi
from conekta.api.subscriptions_api import SubscriptionsApi
from conekta.api.taxes_api import TaxesApi
from conekta.api.tokens_api import TokensApi
from conekta.api.transactions_api import TransactionsApi
from conekta.api.transfers_api import TransfersApi
from conekta.api.webhook_keys_api import WebhookKeysApi
from conekta.api.webhooks_api import WebhooksApi




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt, StrictStr

class SubscriptionResponse(BaseModel):
    """
    subscription model
    """
    billing_cycle_start: Optional[StrictInt] = None
    billing_cycle_end: Optional[StrictInt] = None
    canceled_at: Optional[StrictInt] = None
    card_id: Optional[StrictStr] = None
    charge_id: Optional[StrictStr] = None
    created_at: Optional[StrictInt] = None
    customer_custom_reference: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    last_billing_cycle_order_id: Optional[StrictStr] = None
    object: Optional[StrictStr] = None
    paused_at: Optional[StrictInt] = None
    plan_id: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    subscription_start: Optional[StrictInt] = None
    trial_start: Optional[StrictInt] = None
    trial_end: Optional[StrictInt] = None
    __properties = ["billing_cycle_start", "billing_cycle_end", "canceled_at", "card_id", "charge_id", "created_at", "customer_custom_reference", "customer_id", "id", "last_billing_cycle_order_id", "object", "paused_at", "plan_id", "status", "subscription_start", "trial_start", "trial_end"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SubscriptionResponse:
        """Create an instance of SubscriptionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if billing_cycle_start (nullable) is None
        # and __fields_set__ contains the field
        if self.billing_cycle_start is None and "billing_cycle_start" in self.__fields_set__:
            _dict['billing_cycle_start'] = None

        # set to None if billing_cycle_end (nullable) is None
        # and __fields_set__ contains the field
        if self.billing_cycle_end is None and "billing_cycle_end" in self.__fields_set__:
            _dict['billing_cycle_end'] = None

        # set to None if canceled_at (nullable) is None
        # and __fields_set__ contains the field
        if self.canceled_at is None and "canceled_at" in self.__fields_set__:
            _dict['canceled_at'] = None

        # set to None if charge_id (nullable) is None
        # and __fields_set__ contains the field
        if self.charge_id is None and "charge_id" in self.__fields_set__:
            _dict['charge_id'] = None

        # set to None if paused_at (nullable) is None
        # and __fields_set__ contains the field
        if self.paused_at is None and "paused_at" in self.__fields_set__:
            _dict['paused_at'] = None

        # set to None if trial_start (nullable) is None
        # and __fields_set__ contains the field
        if self.trial_start is None and "trial_start" in self.__fields_set__:
            _dict['trial_start'] = None

        # set to None if trial_end (nullable) is None
        # and __fields_set__ contains the field
        if self.trial_end is None and "trial_end" in self.__fields_set__:
            _dict['trial_end'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SubscriptionResponse:
        """Create an instance of SubscriptionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SubscriptionResponse.parse_obj(obj)

        _obj = SubscriptionResponse.parse_obj({
            "billing_cycle_start": obj.get("billing_cycle_start"),
            "billing_cycle_end": obj.get("billing_cycle_end"),
            "canceled_at": obj.get("canceled_at"),
            "card_id": obj.get("card_id"),
            "charge_id": obj.get("charge_id"),
            "created_at": obj.get("created_at"),
            "customer_custom_reference": obj.get("customer_custom_reference"),
            "customer_id": obj.get("customer_id"),
            "id": obj.get("id"),
            "last_billing_cycle_order_id": obj.get("last_billing_cycle_order_id"),
            "object": obj.get("object"),
            "paused_at": obj.get("paused_at"),
            "plan_id": obj.get("plan_id"),
            "status": obj.get("status"),
            "subscription_start": obj.get("subscription_start"),
            "trial_start": obj.get("trial_start"),
            "trial_end": obj.get("trial_end")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class PaymentMethodCardResponse(BaseModel):
    """
    PaymentMethodCardResponse
    """
    type: StrictStr = Field(...)
    id: StrictStr = Field(...)
    object: StrictStr = Field(...)
    created_at: StrictInt = Field(...)
    parent_id: Optional[StrictStr] = None
    last4: Optional[StrictStr] = None
    bin: Optional[StrictStr] = None
    card_type: Optional[StrictStr] = None
    exp_month: Optional[StrictStr] = None
    exp_year: Optional[StrictStr] = None
    brand: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    default: Optional[StrictBool] = None
    visible_on_checkout: Optional[StrictBool] = None
    payment_source_status: Optional[StrictStr] = None
    __properties = ["type", "id", "object", "created_at", "parent_id", "last4", "bin", "card_type", "exp_month", "exp_year", "brand", "name", "default", "visible_on_checkout", "payment_source_status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PaymentMethodCardResponse:
        """Create an instance of PaymentMethodCardResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PaymentMethodCardResponse:
        """Create an instance of PaymentMethodCardResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PaymentMethodCardResponse.parse_obj(obj)

        _obj = PaymentMethodCardResponse.parse_obj({
            "type": obj.get("type"),
            "id": obj.get("id"),
            "object": obj.get("object"),
            "created_at": obj.get("created_at"),
            "parent_id": obj.get("parent_id"),
            "last4": obj.get("last4"),
            "bin": obj.get("bin"),
            "card_type": obj.get("card_type"),
            "exp_month": obj.get("exp_month"),
            "exp_year": obj.get("exp_year"),
            "brand": obj.get("brand"),
            "name": obj.get("name"),
            "default": obj.get("default"),
            "visible_on_checkout": obj.get("visible_on_checkout"),
            "payment_source_status": obj.get("payment_source_status")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.api_keys_api import ApiKeysApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestApiKeysApi(unittest.TestCase):
    """ApiKeysApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.api_keys_api.ApiKeysApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_key(self):
        """Test case for create_api_key

        Create Api Key  # noqa: E501
        """
        accept_language = 'es'
        api_key_request = conekta.ApiKeyRequest(
            active=True,
            description='description',
            role='private'
        )
        response = self.api.create_api_key(api_key_request, accept_language)
        self.assertIsNotNone(response)

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Delete Api Key  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_api_key('64625cc9f3e02c00163f5e4d', accept_language)
        self.assertIsNotNone(response)

    def test_get_api_key(self):
        """Test case for get_api_key

        Get Api Key  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_api_key('64625cc9f3e02c00163f5e4d', accept_language)
        self.assertIsNotNone(response)

    def test_get_api_keys(self):
        """Test case for get_api_keys

        Get list of Api Keys  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_api_keys(accept_language, limit=20)
        self.assertIsNotNone(response)

    def test_update_api_key(self):
        """Test case for update_api_key

        Update Api Key  # noqa: E501
        """
        accept_language = 'es'
        api_key_update_request = conekta.ApiKeyUpdateRequest(
            active=False,
            description='description'
        )
        response = self.api.update_api_key('64625cc9f3e02c00163f5e4d', accept_language, api_key_update_request)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.antifraud_api import AntifraudApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestAntifraudApi(unittest.TestCase):
    """AntifraudApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.antifraud_api.AntifraudApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_rule_blacklist(self):
        """Test case for create_rule_blacklist

        Create blacklisted rule  # noqa: E501
        """
        accept_language = 'es'
        create_risk_rules_data = conekta.CreateRiskRulesData(
            description='description',
            field='field',
            value='value'
        )
        response = self.api.create_rule_blacklist(create_risk_rules_data, accept_language)
        self.assertIsNotNone(response)

    def test_create_rule_whitelist(self):
        """Test case for create_rule_whitelist

        Create whitelisted rule  # noqa: E501
        """
        accept_language = 'es'
        create_risk_rules_data = conekta.CreateRiskRulesData(
            description='description',
            field='field',
            value='value'
        )
        response = self.api.create_rule_whitelist(accept_language, create_risk_rules_data)
        self.assertIsNotNone(response)

    def test_delete_rule_blacklist(self):
        """Test case for delete_rule_blacklist

        Delete blacklisted rule  # noqa: E501
        """
        response = self.api.delete_rule_blacklist('618c3f30db8b8da9be376b1e')
        self.assertIsNotNone(response)

    def test_delete_rule_whitelist(self):
        """Test case for delete_rule_whitelist

        Delete whitelisted rule  # noqa: E501
        """
        response = self.api.delete_rule_whitelist('618c3f30db8b8da9be376b1e')
        self.assertIsNotNone(response)

    def test_get_rule_blacklist(self):
        """Test case for get_rule_blacklist

        Get list of blacklisted rules  # noqa: E501
        """
        response = self.api.get_rule_blacklist('618c3f30db8b8da9be376b1e')
        self.assertIsNotNone(response)

    def test_get_rule_whitelist(self):
        """Test case for get_rule_whitelist

        Get a list of whitelisted rules  # noqa: E501
        """
        response = self.api.get_rule_whitelist('618c3f30db8b8da9be376b1e')
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.payment_link_api import PaymentLinkApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestPaymentLinkApi(unittest.TestCase):
    """PaymentLinkApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.payment_link_api.PaymentLinkApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_checkout(self):
        """Test case for cancel_checkout

        Cancel Payment Link  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.cancel_checkout('ff6918c6-5043-43b9-a7ec-d40d407d62c1', accept_language)
        self.assertIsNotNone(response)

    def test_create_checkout(self):
        """Test case for create_checkout

        Create Unique Payment Link  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.Checkout(
            allowed_payment_methods=['cash'],
            expires_at=1231223,
            name='test',
            recurrent=False,
            type='PaymentLink',
            order_template=conekta.CheckoutOrderTemplate(
                currency='MXN',
                line_items=[conekta.Product(
                    name='Product',
                    unit_price=10000,
                    quantity=1
                )]
            )
        )
        response = self.api.create_checkout(rq, accept_language)
        self.assertIsNotNone(response)

    def test_email_checkout(self):
        """Test case for email_checkout

        Send an email  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.EmailCheckoutRequest(
            email='foo@email.com'
        )
        response = self.api.email_checkout('ff6918c6-5043-43b9-a7ec-d40d407d62c1', rq, accept_language)
        self.assertIsNotNone(response)

    def test_get_checkout(self):
        """Test case for get_checkout

        Get a payment link by ID  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_checkout('ff6918c6-5043-43b9-a7ec-d40d407d62c1', accept_language)
        self.assertIsNotNone(response)

    def test_get_checkouts(self):
        """Test case for get_checkouts

        Get a list of payment links  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_checkouts(accept_language, limit=2)
        self.assertIsNotNone(response)

    def test_sms_checkout(self):
        """Test case for sms_checkout

        Send an sms  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.SmsCheckoutRequest(
            phonenumber='5534234343'
        )
        response = self.api.sms_checkout('ff6918c6-5043-43b9-a7ec-d40d407d62c1', rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr

class CustomerShippingContactsResponseAddress(BaseModel):
    """
    CustomerShippingContactsResponseAddress
    """
    object: Optional[StrictStr] = None
    street1: Optional[StrictStr] = None
    street2: Optional[StrictStr] = None
    postal_code: Optional[StrictStr] = None
    city: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    residential: Optional[StrictBool] = None
    __properties = ["object", "street1", "street2", "postal_code", "city", "state", "country", "residential"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CustomerShippingContactsResponseAddress:
        """Create an instance of CustomerShippingContactsResponseAddress from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CustomerShippingContactsResponseAddress:
        """Create an instance of CustomerShippingContactsResponseAddress from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CustomerShippingContactsResponseAddress.parse_obj(obj)

        _obj = CustomerShippingContactsResponseAddress.parse_obj({
            "object": obj.get("object"),
            "street1": obj.get("street1"),
            "street2": obj.get("street2"),
            "postal_code": obj.get("postal_code"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "country": obj.get("country"),
            "residential": obj.get("residential")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr, conint, constr

class UpdateOrderTaxResponse(BaseModel):
    """
    create new taxes for an existing order response
    """
    amount: conint(strict=True, ge=0) = Field(..., description="The amount to be collected for tax in cents")
    description: constr(strict=True, min_length=2) = Field(..., description="description or tax's name")
    metadata: Optional[Dict[str, Any]] = None
    id: StrictStr = Field(...)
    object: Optional[StrictStr] = None
    parent_id: Optional[StrictStr] = None
    __properties = ["amount", "description", "metadata", "id", "object", "parent_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateOrderTaxResponse:
        """Create an instance of UpdateOrderTaxResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateOrderTaxResponse:
        """Create an instance of UpdateOrderTaxResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateOrderTaxResponse.parse_obj(obj)

        _obj = UpdateOrderTaxResponse.parse_obj({
            "amount": obj.get("amount"),
            "description": obj.get("description"),
            "metadata": obj.get("metadata"),
            "id": obj.get("id"),
            "object": obj.get("object"),
            "parent_id": obj.get("parent_id")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator
from conekta.models.company_fiscal_info_response import CompanyFiscalInfoResponse
from conekta.models.company_payout_destination_response import CompanyPayoutDestinationResponse

class CompanyResponse(BaseModel):
    """
    Company model
    """
    id: Optional[StrictStr] = Field(None, description="The child company's unique identifier")
    created_at: Optional[StrictInt] = Field(None, description="The resource's creation date (unix timestamp)")
    name: Optional[StrictStr] = Field(None, description="The child company's name")
    object: Optional[StrictStr] = Field(None, description="The resource's type")
    parent_company_id: Optional[StrictStr] = Field(None, description="Id of the parent company")
    use_parent_fiscal_data: Optional[StrictBool] = Field(None, description="Whether the parent company's fiscal data is to be used for liquidation and tax purposes")
    payout_destination: Optional[CompanyPayoutDestinationResponse] = None
    fiscal_info: Optional[CompanyFiscalInfoResponse] = None
    __properties = ["id", "created_at", "name", "object", "parent_company_id", "use_parent_fiscal_data", "payout_destination", "fiscal_info"]

    @validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('company'):
            raise ValueError("must be one of enum values ('company')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CompanyResponse:
        """Create an instance of CompanyResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of payout_destination
        if self.payout_destination:
            _dict['payout_destination'] = self.payout_destination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fiscal_info
        if self.fiscal_info:
            _dict['fiscal_info'] = self.fiscal_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CompanyResponse:
        """Create an instance of CompanyResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CompanyResponse.parse_obj(obj)

        _obj = CompanyResponse.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "name": obj.get("name"),
            "object": obj.get("object"),
            "parent_company_id": obj.get("parent_company_id"),
            "use_parent_fiscal_data": obj.get("use_parent_fiscal_data"),
            "payout_destination": CompanyPayoutDestinationResponse.from_dict(obj.get("payout_destination")) if obj.get("payout_destination") is not None else None,
            "fiscal_info": CompanyFiscalInfoResponse.from_dict(obj.get("fiscal_info")) if obj.get("fiscal_info") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from conekta.models.webhook_key_response import WebhookKeyResponse

class GetWebhookKeysResponse(BaseModel):
    """
    GetWebhookKeysResponse
    """
    has_more: StrictBool = Field(..., description="Indicates if there are more pages to be requested")
    object: StrictStr = Field(..., description="Object type, in this case is list")
    next_page_url: Optional[StrictStr] = Field(None, description="URL of the next page.")
    previous_page_url: Optional[StrictStr] = Field(None, description="Url of the previous page.")
    data: Optional[conlist(WebhookKeyResponse)] = None
    __properties = ["has_more", "object", "next_page_url", "previous_page_url", "data"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetWebhookKeysResponse:
        """Create an instance of GetWebhookKeysResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item in self.data:
                if _item:
                    _items.append(_item.to_dict())
            _dict['data'] = _items
        # set to None if next_page_url (nullable) is None
        # and __fields_set__ contains the field
        if self.next_page_url is None and "next_page_url" in self.__fields_set__:
            _dict['next_page_url'] = None

        # set to None if previous_page_url (nullable) is None
        # and __fields_set__ contains the field
        if self.previous_page_url is None and "previous_page_url" in self.__fields_set__:
            _dict['previous_page_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetWebhookKeysResponse:
        """Create an instance of GetWebhookKeysResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetWebhookKeysResponse.parse_obj(obj)

        _obj = GetWebhookKeysResponse.parse_obj({
            "has_more": obj.get("has_more"),
            "object": obj.get("object"),
            "next_page_url": obj.get("next_page_url"),
            "previous_page_url": obj.get("previous_page_url"),
            "data": [WebhookKeyResponse.from_dict(_item) for _item in obj.get("data")] if obj.get("data") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator

class CompanyFiscalInfoAddressResponse(BaseModel):
    """
    Company fiscal info address model
    """
    object: Optional[StrictStr] = Field(None, description="The resource's type")
    street1: Optional[StrictStr] = Field(None, description="Street Address")
    street2: Optional[StrictStr] = Field(None, description="Colonia")
    city: Optional[StrictStr] = Field(None, description="City")
    state: Optional[StrictStr] = Field(None, description="State")
    country: Optional[StrictStr] = Field(None, description="Country")
    postal_code: Optional[StrictStr] = Field(None, description="Postal code")
    external_number: Optional[StrictStr] = Field(None, description="Street number")
    internal_number: Optional[StrictStr] = Field(None, description="Unit / apartment number")
    __properties = ["object", "street1", "street2", "city", "state", "country", "postal_code", "external_number", "internal_number"]

    @validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('address'):
            raise ValueError("must be one of enum values ('address')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CompanyFiscalInfoAddressResponse:
        """Create an instance of CompanyFiscalInfoAddressResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CompanyFiscalInfoAddressResponse:
        """Create an instance of CompanyFiscalInfoAddressResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CompanyFiscalInfoAddressResponse.parse_obj(obj)

        _obj = CompanyFiscalInfoAddressResponse.parse_obj({
            "object": obj.get("object"),
            "street1": obj.get("street1"),
            "street2": obj.get("street2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "country": obj.get("country"),
            "postal_code": obj.get("postal_code"),
            "external_number": obj.get("external_number"),
            "internal_number": obj.get("internal_number")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.shipping_contacts_api import ShippingContactsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestShippingContactsApi(unittest.TestCase):
    """ShippingContactsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.shipping_contacts_api.ShippingContactsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer_shipping_contacts(self):
        """Test case for create_customer_shipping_contacts

        Create a shipping contacts  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.CustomerShippingContacts(
            address=conekta.CustomerShippingContactsAddress(
                street1='street'
            )
        )
        response = self.api.create_customer_shipping_contacts('cus_2tYENskzTjjgkGQLt', rq, accept_language)
        self.assertIsNotNone(response)

    def test_delete_customer_shipping_contacts(self):
        """Test case for delete_customer_shipping_contacts

        Delete shipping contacts  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_customer_shipping_contacts('cus_2tYENskzTjjgkGQLt', 'ship_cont_2tY2ncFSBLUaohto2',
                                                              accept_language)
        self.assertIsNotNone(response)

    def test_update_customer_shipping_contacts(self):
        """Test case for update_customer_shipping_contacts

        Update shipping contacts  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.CustomerUpdateShippingContacts(
            address=conekta.CustomerShippingContactsAddress(
                street1='street'
            )
        )
        response = self.api.update_customer_shipping_contacts('cus_2tYENskzTjjgkGQLt', 'ship_cont_2tY2ncFSBLUaohto2',
                                                              rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from conekta.models.charge_response_channel import ChargeResponseChannel
from conekta.models.charge_response_payment_method import ChargeResponsePaymentMethod
from conekta.models.charge_response_refunds import ChargeResponseRefunds

class ChargesDataResponse(BaseModel):
    """
    ChargesDataResponse
    """
    amount: Optional[StrictInt] = None
    channel: Optional[ChargeResponseChannel] = None
    created_at: Optional[StrictInt] = None
    currency: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    device_fingerprint: Optional[StrictStr] = None
    failure_code: Optional[StrictStr] = None
    failure_message: Optional[StrictStr] = None
    fee: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    livemode: Optional[StrictBool] = None
    object: Optional[StrictStr] = None
    order_id: Optional[StrictStr] = None
    paid_at: Optional[StrictInt] = None
    payment_method: Optional[ChargeResponsePaymentMethod] = None
    reference_id: Optional[StrictStr] = Field(None, description="Reference ID of the charge")
    refunds: Optional[ChargeResponseRefunds] = None
    status: Optional[StrictStr] = None
    __properties = ["amount", "channel", "created_at", "currency", "customer_id", "description", "device_fingerprint", "failure_code", "failure_message", "fee", "id", "livemode", "object", "order_id", "paid_at", "payment_method", "reference_id", "refunds", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargesDataResponse:
        """Create an instance of ChargesDataResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of channel
        if self.channel:
            _dict['channel'] = self.channel.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_method
        if self.payment_method:
            _dict['payment_method'] = self.payment_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of refunds
        if self.refunds:
            _dict['refunds'] = self.refunds.to_dict()
        # set to None if paid_at (nullable) is None
        # and __fields_set__ contains the field
        if self.paid_at is None and "paid_at" in self.__fields_set__:
            _dict['paid_at'] = None

        # set to None if reference_id (nullable) is None
        # and __fields_set__ contains the field
        if self.reference_id is None and "reference_id" in self.__fields_set__:
            _dict['reference_id'] = None

        # set to None if refunds (nullable) is None
        # and __fields_set__ contains the field
        if self.refunds is None and "refunds" in self.__fields_set__:
            _dict['refunds'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargesDataResponse:
        """Create an instance of ChargesDataResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChargesDataResponse.parse_obj(obj)

        _obj = ChargesDataResponse.parse_obj({
            "amount": obj.get("amount"),
            "channel": ChargeResponseChannel.from_dict(obj.get("channel")) if obj.get("channel") is not None else None,
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "customer_id": obj.get("customer_id"),
            "description": obj.get("description"),
            "device_fingerprint": obj.get("device_fingerprint"),
            "failure_code": obj.get("failure_code"),
            "failure_message": obj.get("failure_message"),
            "fee": obj.get("fee"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "object": obj.get("object"),
            "order_id": obj.get("order_id"),
            "paid_at": obj.get("paid_at"),
            "payment_method": ChargeResponsePaymentMethod.from_dict(obj.get("payment_method")) if obj.get("payment_method") is not None else None,
            "reference_id": obj.get("reference_id"),
            "refunds": ChargeResponseRefunds.from_dict(obj.get("refunds")) if obj.get("refunds") is not None else None,
            "status": obj.get("status")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.subscriptions_api import SubscriptionsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.subscriptions_api.SubscriptionsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_subscription(self):
        """Test case for cancel_subscription

        Cancel Subscription  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.cancel_subscription('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_create_subscription(self):
        """Test case for create_subscription

        Create Subscription  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.SubscriptionRequest(
            plan_id='plan_id'
        )
        response = self.api.create_subscription('cus_2tYENskzTjjgkGQLt', rq, accept_language)
        self.assertIsNotNone(response)

    def test_get_all_events_from_subscription(self):
        """Test case for get_all_events_from_subscription

        Get Events By Subscription  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_all_events_from_subscription('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_get_subscription(self):
        """Test case for get_subscription

        Get Subscription  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_subscription('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_pause_subscription(self):
        """Test case for pause_subscription

        Pause Subscription  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.pause_subscription('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_resume_subscription(self):
        """Test case for resume_subscription

        Resume Subscription  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.resume_subscription('cus_2tYENskzTjjgkGQLt', accept_language)
        self.assertIsNotNone(response)

    def test_update_subscription(self):
        """Test case for update_subscription

        Update Subscription  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.SubscriptionUpdateRequest(
            plan_id='plan_id'
        )
        response = self.api.update_subscription('cus_2tYENskzTjjgkGQLt', rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool, constr, validator

class WebhookRequest(BaseModel):
    """
    a webhook
    """
    url: constr(strict=True) = Field(..., description="Here you must place the URL of your Webhook remember that you must program what you will do with the events received. Also do not forget to handle the HTTPS protocol for greater security.")
    synchronous: StrictBool = Field(..., description="It is a value that allows to decide if the events will be synchronous or asynchronous. We recommend asynchronous = false")
    __properties = ["url", "synchronous"]

    @validator('url')
    def url_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^(?!.*(localhost|127\.0\.0\.1)).*$", value):
            raise ValueError(r"must validate the regular expression /^(?!.*(localhost|127\.0\.0\.1)).*$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebhookRequest:
        """Create an instance of WebhookRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebhookRequest:
        """Create an instance of WebhookRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebhookRequest.parse_obj(obj)

        _obj = WebhookRequest.parse_obj({
            "url": obj.get("url"),
            "synchronous": obj.get("synchronous") if obj.get("synchronous") is not None else False
        })
        return _obj

